@@ -1,5 +1,5 @@
 # Trosnoth (UberTweak Platform Game)
-# Copyright (C) 2006-2009 Joshua D Bartlett
+# Copyright (C) 2006-2010 Joshua D Bartlett
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -26,15 +26,15 @@ import pygame.locals as pgLocals
 from math import sin, atan
 from copy import copy
 
-from trosnoth.src.model.universe import Universe
-from trosnoth.src.model.mapblocks import ForwardInterfaceMapBlock, InterfaceMapBlock, \
+from trosnoth.model.universe import Universe
+from trosnoth.model.mapblocks import ForwardInterfaceMapBlock, InterfaceMapBlock, \
      BackwardInterfaceMapBlock, TopBodyMapBlock, BottomBodyMapBlock, BodyMapBlock
-from trosnoth.src.model.map import MapLayout
-from trosnoth.src.gui.framework import elements, framework
-from trosnoth.src.gui import app
-from trosnoth.src.utils.utils import new
-from trosnoth.src.utils.math import distance
-from trosnoth.src.utils.unrepr import unrepr
+from trosnoth.model.map import MapLayout
+from trosnoth.gui.framework import elements, framework
+from trosnoth.gui import app
+from trosnoth.utils.utils import new
+from trosnoth.utils.math import distance
+from trosnoth.utils.unrepr import unrepr
 
 from trosnoth.data import getPath, makeDirs, user
 
