@@ -1,5 +1,5 @@
 # Trosnoth (UberTweak Platform Game)
-# Copyright (C) 2006-2009 Joshua D Bartlett
+# Copyright (C) 2006-2010 Joshua D Bartlett
 #
 # This program is free software; you can redistribute it and/or
 # modify it under the terms of the GNU General Public License
@@ -19,13 +19,13 @@
 import pygame
 import os
 
-from trosnoth.src.gui.framework import framework, elements, listbox, checkbox
-from trosnoth.src.model.mapblocks import ForwardInterfaceMapBlock, InterfaceMapBlock, \
+from trosnoth.gui.framework import framework, elements, listbox, checkbox
+from trosnoth.model.mapblocks import ForwardInterfaceMapBlock, InterfaceMapBlock, \
      BackwardInterfaceMapBlock, TopBodyMapBlock, BottomBodyMapBlock, BodyMapBlock
 blocks = [ForwardInterfaceMapBlock, BackwardInterfaceMapBlock, TopBodyMapBlock, BottomBodyMapBlock]
 
-from trosnoth.src.gui.fonts.font import ScaledFont
-from trosnoth.src.gui.common import FullScreenAttachedPoint, ScaledSize, Location, Area
+from trosnoth.gui.fonts.font import ScaledFont
+from trosnoth.gui.common import FullScreenAttachedPoint, ScaledSize, Location, Area
 
 class Interface(framework.CompoundElement):
     def __init__(self, mapBlockCreator):
